==> voreen-src-5.1.0-win.zip: voreen-src-win32-nightly/modules/bigdataimageprocessing/volumefilterproperties/filterproperties.cpp <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2019 University of Muenster, Germany,                        *
 * Department of Computer Science.                                                 *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#include "filterproperties.h"

#include <boost/algorithm/string.hpp>

namespace voreen {

const int FilterProperties::DEFAULT_SETTINGS = -1;
const std::string FilterProperties::loggerCat_ = "voreen.base.VolumeFilterList";

FilterProperties::~FilterProperties() {
}

const std::vector<Property*>& FilterProperties::getProperties() const {
    return properties_;
}

void FilterProperties::storeVisibility() {
    for (Property* property : properties_) {
        visibilityMap_[property] = property->isVisibleFlagSet();
    }
}
void FilterProperties::restoreVisibility() {
    for (Property* property : properties_) {
        property->setVisibleFlag(visibilityMap_[property]);
    }
}

std::string FilterProperties::getId(const std::string& id) const {
    std::string name = getVolumeFilterName();
    boost::algorithm::replace_all(name, " ", "_");
    return name + "_" + id;
}

}

==> voreen-src-5.2.0-win.zip: voreen-src-win32-nightly/modules/bigdataimageprocessing/volumefilterproperties/filterproperties.cpp <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2021 University of Muenster, Germany,                        *
 * Department of Computer Science.                                                 *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#include "filterproperties.h"

namespace voreen {

const std::string FilterProperties::loggerCat_ = "voreen.base.VolumeFilterList";

FilterProperties::~FilterProperties() {
}

const std::vector<Property*>& FilterProperties::getProperties() const {
    return properties_;
}

void FilterProperties::storeVisibility() {
    for (Property* property : properties_) {
        visibilityMap_[property] = property->isVisibleFlagSet();
    }
}
void FilterProperties::restoreVisibility() {
    for (Property* property : properties_) {
        property->setVisibleFlag(visibilityMap_[property]);
    }
}

std::string FilterProperties::getId(const std::string& id) const {
    std::string name = getVolumeFilterName();
    for(auto& c : name) {
        if(c == ' ') {
            c = '_';
        }
    }
    return name + "_" + id;
}

}
